@@ -11,7 +11,7 @@ use Moo;
 use namespace::clean;
 
 # Version.
-our $VERSION = 0.05;
+our $VERSION = 0.06;
 
 # Get XML.
 has xml => (
@@ -194,37 +194,21 @@ L<namespace::clean>.
 
 =head1 SEE ALSO
 
-L<Map::Tube>,
-L<Map::Tube::Graph>,
-L<Map::Tube::GraphViz>,
-L<Map::Tube::Plugin::Graph>,
-L<Map::Tube::Text::Table>,
-L<Task::Map::Tube>.
+=over
 
-L<Map::Tube::Barcelona>,
-L<Map::Tube::Berlin>,
-L<Map::Tube::Budapest>,
-L<Map::Tube::Delhi>,
-L<Map::Tube::Dnipropetrovsk>,
-L<Map::Tube::Kazan>,
-L<Map::Tube::Kharkiv>,
-L<Map::Tube::Kiev>,
-L<Map::Tube::London>,
-L<Map::Tube::Minsk>,
-L<Map::Tube::Moscow>,
-L<Map::Tube::NYC>,
-L<Map::Tube::Nanjing>,
-L<Map::Tube::Novosibirsk>,
-L<Map::Tube::Prague>,
-L<Map::Tube::SaintPetersburg>,
-L<Map::Tube::Samara>,
-L<Map::Tube::Singapore>,
-L<Map::Tube::Sofia>,
-L<Map::Tube::Tbilisi>,
-L<Map::Tube::Tokyo>,
-L<Map::Tube::Vienna>,
-L<Map::Tube::Warsaw>,
-L<Map::Tube::Yekaterinburg>.
+=item L<Map::Tube>
+
+Core library as Role (Moo) to process map data.
+
+=item L<Task::Map::Tube>
+
+Install the Map::Tube modules.
+
+=item L<Task::Map::Tube::Metro>
+
+Install the Map::Tube concrete metro modules.
+
+=back
 
 =head1 REPOSITORY
 
@@ -244,6 +228,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.05
+0.06
 
 =cut
